@@ -73,6 +73,7 @@ def command(login_required=True):
     """a decorator for handling authentication and exceptions"""
     def decorate(f):
         def wrapper(self, *args):
+            from dropbox import rest
             if login_required and not self.sess.is_linked():
               log.FatalError("dpbx Cannot login: check your credentials",log.ErrorCode.dpbx_nologin)
               return
@@ -81,7 +82,7 @@ def command(login_required=True):
                 return f(self, *args)
             except TypeError, e:
                 log_exception(e)
-                log.FatalError('dpbx type error "%s"' % (e,), log.ErrorCode.backend_code_error)
+                log.FatalError('dpbx type error "%s"' % (str(e),), log.ErrorCode.backend_code_error)
             except rest.ErrorResponse, e:
                 msg = e.user_error_msg or str(e)
                 log.Error('dpbx error: %s' % (msg,), log.ErrorCode.backend_command_error)
