@@ -65,9 +65,10 @@ commands = ["cleanup",
             ]
 
 def old_fn_deprecation(opt):
-    print >> sys.stderr, _("Warning: Option %s is pending deprecation "
-                          "and will be removed in a future release.\n"
-                          "Use of default filenames is strongly suggested.") % opt
+    log.Log(_("Warning: Option %s is pending deprecation "
+              "and will be removed in a future release.\n"
+              "Use of default filenames is strongly suggested.") % opt,
+            log.ERROR, force_print=True)
 
 def expand_fn(filename):
     return os.path.expanduser(os.path.expandvars(filename))
@@ -329,6 +330,15 @@ def parse_cmdline_options(arglist):
 
     # used to provide a prefix on top of the defaul tar file name
     parser.add_option("--file-prefix", type = "string", dest = "file_prefix", action = "store")
+    
+    # used to provide a suffix for manifest files only
+    parser.add_option("--file-prefix-manifest", type = "string", dest = "file_prefix_manifest", action = "store")
+
+    # used to provide a suffix for archive files only
+    parser.add_option("--file-prefix-archive", type = "string", dest = "file_prefix_archive", action = "store")
+
+    # used to provide a suffix for sigature files only
+    parser.add_option("--file-prefix-signature", type = "string", dest = "file_prefix_signature", action = "store")
 
     # used in testing only - skips upload for a given volume
     parser.add_option("--skip-volume", type = "int",
@@ -441,6 +451,9 @@ def parse_cmdline_options(arglist):
                       callback = lambda o, s, v, p: (setattr(p.values, o.dest, True),
                                                    old_fn_deprecation(s)))
 
+    # Level of Redundancy in % for Par2 files
+    parser.add_option("--par2-redundancy", type="int", metavar=_("number"))
+
     # Used to display the progress for the full and incremental backup operations
     parser.add_option("--progress", action = "store_true")
 
@@ -486,11 +499,22 @@ def parse_cmdline_options(arglist):
     parser.add_option("--s3-multipart-chunk-size", type = "int", action = "callback", metavar = _("number"),
                       callback = lambda o, s, v, p: setattr(p.values, "s3_multipart_chunk_size", v * 1024 * 1024))
 
+    # Number of processes to set the Processor Pool to when uploading multipart
+    # uploads to S3. Use this to control the maximum simultaneous uploads to S3.
+    parser.add_option("--s3-multipart-max-procs", type="int", metavar=_("number"))
+
+    # Number of seconds to wait for each part of a multipart upload to S3. Use this
+    # to prevent hangups when doing a multipart upload to S3.
+    parser.add_option("--s3_multipart_max_timeout", type="int", metavar=_("number"))
+
     # Option to allow the s3/boto backend use the multiprocessing version.
     # By default it is off since it does not work for Python 2.4 or 2.5.
     if sys.version_info[:2] >= (2, 6):
         parser.add_option("--s3-use-multiprocessing", action = "store_true")
 
+    # Option to allow use of server side encryption in s3
+    parser.add_option("--s3-use-server-side-encryption", action="store_true", dest="s3_use_sse")
+
     # scp command to use (ssh pexpect backend)
     parser.add_option("--scp-command", metavar = _("command"))
 
@@ -498,7 +522,7 @@ def parse_cmdline_options(arglist):
     parser.add_option("--sftp-command", metavar = _("command"))
 
     # sftp command to use (ssh pexpect backend)
-    parser.add_option("--cf-command", metavar = _("command"))
+    parser.add_option("--cf-backend", metavar = _("pyrax|cloudfiles"))
 
     # If set, use short (< 30 char) filenames for all the remote files.
     parser.add_option("--short-filenames", action = "callback",
